@@ -7,7 +7,7 @@ use LWP;
 use JSON;
 use String::Random;
 
-our $VERSION = "1.03";
+our $VERSION = "1.04";
 
 has 'server' => (
     is       => 'rw',
@@ -27,7 +27,7 @@ has 'post_response'		=> ( is => 'ro');
 has 'last_response'		=> ( is => 'ro', );
 has 'json_request'		=> ( is => 'ro');
 has 'json_response'		=> ( is => 'ro');
-has 'verify_hostname'	=> ( is => 'rw', default => 1);
+has 'verify_hostname'	=> ( is => 'rw', default => sub {1} );
 has 'ssl_opts'			=> ( is => 'rw');
 
 my @content_type = ( 'content-type', 'application/json', );
@@ -86,10 +86,7 @@ sub do {
         auth    => $auth,
         params  => \%args,
     };
-	use Data::Dumper;
-	print Dumper %args;
     my $json = encode_json($json_data) or die($!);
-	print $json;
     $self->{post_response} = $ua->post( $url, @content_type, Content => $json );
 	$self->{json_request} = $self->{post_response}->{'_request'}->{_content};
 	$self->{json_response} = $self->{post_response}->{_content};
@@ -227,7 +224,7 @@ The L<HTTP::Response> from the Zabbix server for the most recent request.
 
 =head1 BUGS and CAVEATS
 
-Probaly bugs.
+Probably bugs.
 
 =head1 NOTES
 
